@@ -1,7 +1,10 @@
 from dragoneye.cloud_scanner.aws.aws_scan_settings import AwsCloudScanSettings
 from dragoneye.cloud_scanner.azure.azure_scan_settings import AzureCloudScanSettings
+from dragoneye.cloud_scanner.gcp.gcp_scan_settings import GcpCloudScanSettings
 from dragoneye.cloud_scanner.aws.aws_scanner import AwsScanner
 from dragoneye.cloud_scanner.azure.azure_scanner import AzureScanner
+from dragoneye.cloud_scanner.gcp.gcp_scanner import GcpScanner
 from dragoneye.cloud_scanner.aws.aws_session_factory import AwsSessionFactory
 from dragoneye.cloud_scanner.azure.azure_authorizer import AzureAuthorizer
+from dragoneye.cloud_scanner.gcp.gcp_credentials_factory import GcpCredentialsFactory
 from dragoneye.utils.app_logger import logger, add_file_handler
