@@ -8,7 +8,7 @@ from dragoneye.utils.app_logger import logger
 RATE_ERRORS = ['Throttling', 'TooManyRequestsException']
 
 
-def rate_limiter(max_attempts=10):
+def rate_limiter(max_attempts=3):
     def decorator(func):
         @functools.wraps(func)
         def decorated(*args, **kwargs):
@@ -23,7 +23,7 @@ def rate_limiter(max_attempts=10):
                     logger.warning(f'Throttling error on operation: {ex.operation_name} on attempt #{attempt}/{max_attempts}')
                     if attempt >= max_attempts:
                         raise ex
-                    sleep_period = (2 ** attempt) - 1
+                    sleep_period = 2 ** (attempt + 2)
                     time.sleep(sleep_period)
 
         return decorated
